@@ -6,3 +6,7 @@ from bibtutils import gcp
 from bibtutils import slack
 
 """A Python package featuring functionality often used by BITS Blue Team (BIBT)."""
+
+import logging
+
+logging.getLogger(__name__).addHandler(logging.NullHandler())
\ No newline at end of file
